@@ -169,7 +169,7 @@ def find_lines_derivative(spectrum, flux_threshold=None):
 
     Parameters
     ----------
-    spectrum : Spectrum1D
+    spectrum : `~specutils.Spectrum1D`
         The spectrum object over which the equivalent width will be calculated.
     flux_threshold : float, `~astropy.units.Quantity` or None
         The threshold a pixel must be above to be considered part of a line. If
@@ -259,15 +259,15 @@ def _generate_line_list_table(spectrum, emission_inds, absorption_inds):
 
 
 def fit_lines(spectrum, model, fitter=fitting.LevMarLSQFitter(calc_uncertainties=True),
-              exclude_regions=None, weights=None, window=None, get_fit_info=False,
-              **kwargs):
+              exclude_regions=None, exclude_region_upper_bounds=False, weights=None,
+              window=None, get_fit_info=False, **kwargs):
     """
     Fit the input models to the spectrum. The parameter values of the
     input models will be used as the initial conditions for the fit.
 
     Parameters
     ----------
-    spectrum : Spectrum1D
+    spectrum : `~specutils.Spectrum1D`
         The spectrum object over which the equivalent width will be calculated.
     model: `~astropy.modeling.Model` or list of `~astropy.modeling.Model`
         The model or list of models that contain the initial guess.
@@ -275,15 +275,20 @@ def fit_lines(spectrum, model, fitter=fitting.LevMarLSQFitter(calc_uncertainties
         Fitter instance to be used when fitting model to spectrum.
     exclude_regions : list of `~specutils.SpectralRegion`
         List of regions to exclude in the fitting.
+    exclude_region_upper_bounds : bool, optional
+        Set to True to override the default pythonic slicing on the excluded regions (inclusive
+        lower bound, exclusive upper bound) and remove spectral values less than or equal to
+        the upper bound of the region rather than strictly less than the upper bound.
     weights : array-like or 'unc', optional
-        If 'unc', the unceratinties from the spectrum object are used to
+        If 'unc', the uncertainties from the spectrum object are used to
         to calculate the weights. If array-like, represents the weights to
         use in the fitting.  Note that if a mask is present on the spectrum, it
         will be applied to the ``weights`` as it would be to the spectrum
         itself.
-    window : `~specutils.SpectralRegion` or list of `~specutils.SpectralRegion`
+    window : `~specutils.SpectralRegion`, `~astropy.units.Quantity`, or list of either
         Regions of the spectrum to use in the fitting. If None, then the
-        whole spectrum will be used in the fitting.\
+        whole spectrum will be used in the fitting. If a single `~astropy.units.Quantity`
+        is input, it will be used as the width of the region around the model mean.
     get_fit_info : bool, optional
         Flag to return the ``fit_info`` from the underlying scipy optimizer used
         in the fitting. If True, the returned model will have a ``fit_info``
@@ -309,7 +314,8 @@ def fit_lines(spectrum, model, fitter=fitting.LevMarLSQFitter(calc_uncertainties
     #
 
     if exclude_regions is not None:
-        spectrum = excise_regions(spectrum, exclude_regions)
+        spectrum = excise_regions(spectrum, exclude_regions,
+                                  inclusive_upper=exclude_region_upper_bounds)
 
     #
     # Make the model a list if not already
@@ -357,6 +363,7 @@ def fit_lines(spectrum, model, fitter=fitting.LevMarLSQFitter(calc_uncertainties
             model_guess,
             fitter=fitter,
             exclude_regions=exclude_regions,
+            exclude_region_upper_bounds=exclude_region_upper_bounds,
             weights=weights,
             window=model_window,
             get_fit_info=get_fit_info,
@@ -376,8 +383,8 @@ def fit_lines(spectrum, model, fitter=fitting.LevMarLSQFitter(calc_uncertainties
 
 
 def _fit_lines(spectrum, model, fitter=fitting.LevMarLSQFitter(calc_uncertainties=True),
-               exclude_regions=None, weights=None, window=None, get_fit_info=False,
-               ignore_units=False, **kwargs):
+               exclude_regions=None, exclude_region_upper_bounds=False, weights=None,
+               window=None, get_fit_info=False, ignore_units=False, **kwargs):
     """
     Fit the input model (initial conditions) to the spectrum.  Output will be
     the same model with the parameters set based on the fitting.
@@ -389,7 +396,8 @@ def _fit_lines(spectrum, model, fitter=fitting.LevMarLSQFitter(calc_uncertaintie
     #
 
     if exclude_regions is not None:
-        spectrum = excise_regions(spectrum, exclude_regions)
+        spectrum = excise_regions(spectrum, exclude_regions,
+                                  inclusive_upper=exclude_region_upper_bounds)
 
     if isinstance(weights, str):
         if weights == 'unc':
@@ -430,16 +438,20 @@ def _fit_lines(spectrum, model, fitter=fitting.LevMarLSQFitter(calc_uncertaintie
 
     # In this case the window defines the area around the center of each model
     window_indices = None
-    if window is not None and isinstance(window, (float, int)):
-        center = model.mean
-        window_indices = np.nonzero((dispersion >= center-window) &
-                                    (dispersion < center+window))
+    if window is not None and isinstance(window, u.Quantity):
+        if isinstance(window.value, (float, int)):
+            center = model.mean
+            window_indices = np.nonzero((dispersion >= center-window) &
+                                        (dispersion < center+window))
+        elif len(window.value) == 2:
+            window_indices = np.nonzero((dispersion >= window.min()) &
+                                        (dispersion <= window.max()))
 
     # In this case the window is the start and end points of where we
     # should fit
     elif window is not None and isinstance(window, tuple):
-        window_indices = np.nonzero((dispersion >= window[0]) &
-                                    (dispersion <= window[1]))
+        window_indices = np.nonzero((dispersion >= min(window)) &
+                                    (dispersion <= max(window)))
 
     # in this case the window is spectral regions that determine where
     # to fit.
